import{_ as c}from"./TasksView.vue_vue_type_script_setup_true_lang.75ae5be0.js";import{L as d}from"./tasksController.cf29452d.js";import{d as f,e as u,o as _,c as m,w as a,b as s,u as o,dd as y,aG as i,bT as k,dh as b,a0 as w}from"./index.f34a21df.js";import{C as T}from"./ContentLayout.ad8d7282.js";import{a as g}from"./ant-design.0ea267a5.js";import"./metadata.d6db5c15.js";import"./PhRobot.vue.1bff4557.js";import"./PhWebhooksLogo.vue.2cc97eed.js";import"./string.258cabc4.js";import"./dayjs.a4679024.js";import"./index.9470b370.js";import"./gateway.2694bf1d.js";import"./popupNotifcation.5e450e3b.js";import"./scripts.6e6452b0.js";import"./record.ca0bcbf9.js";import"./linters.659f9757.js";import"./asyncComputed.398aef1d.js";import"./polling.d60cf48f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="26045541-88e4-41f7-b487-55e12c51e960",e._sentryDebugIdIdentifier="sentry-dbid-26045541-88e4-41f7-b487-55e12c51e960")}catch{}})();const x=f({__name:"Tasks",setup(e){const t=new d,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(p,n)=>(_(),m(T,null,{default:a(()=>[s(o(b),{justify:"space-between",align:"center"},{default:a(()=>[s(o(y),null,{default:a(()=>[i("Tasks")]),_:1}),s(o(k),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:a(()=>[i("Clear all")]),_:1})]),_:1}),s(c,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(t),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.5fc6f2f5.js.map
