import{O as r}from"./workspaceStore.26e825e1.js";import{d as l,X as i,o as u,Y as c,b as o,w as a,u as d,aG as n,dd as f,dc as _}from"./index.f34a21df.js";import"./url.6d3c9ba6.js";import"./colorHelpers.2d661043.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9cd3f938-3080-43dc-9ef7-52111d1b55ff",e._sentryDebugIdIdentifier="sentry-dbid-9cd3f938-3080-43dc-9ef7-52111d1b55ff")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[o(d(f),null,{default:a(()=>[n("You're authenticated")]),_:1}),o(d(_),null,{default:a(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.5a3b0b2e.js.map
