import"./App.vue_vue_type_style_index_0_lang.eb1d2992.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.eb1d2992.js";import"./workspaceStore.26e825e1.js";import"./index.f34a21df.js";import"./url.6d3c9ba6.js";import"./colorHelpers.2d661043.js";import"./PlayerConfigProvider.5238fda3.js";import"./index.b0f063d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="7642ca57-140d-48cf-bfc8-ea2d7d904f61",e._sentryDebugIdIdentifier="sentry-dbid-7642ca57-140d-48cf-bfc8-ea2d7d904f61")}catch{}})();export{b as default};
//# sourceMappingURL=App.87909cc5.js.map
