import{a0 as t,r as c,o as s,c as r}from"./index.f34a21df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e091acaa-9bd4-489b-9345-def3cfcb18e1",e._sentryDebugIdIdentifier="sentry-dbid-e091acaa-9bd4-489b-9345-def3cfcb18e1")}catch{}})();const d={};function a(e,o){const n=c("RouterView");return s(),r(n,{class:"router"})}const f=t(d,[["render",a],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.5bd21bef.js.map
