import{C as t,E as i,K as d,a as f,M as c,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.bc47b262.js";import"./index.f34a21df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="36d4300b-588c-4f41-911a-fa1eaaa4f637",e._sentryDebugIdIdentifier="sentry-dbid-36d4300b-588c-4f41-911a-fa1eaaa4f637")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,f as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.18982481.js.map
