import{O as d}from"./workspaceStore.26e825e1.js";import{d as i,X as l,o as c,Y as f,b as a,w as n,u as o,aG as s,dd as u,dc as b}from"./index.f34a21df.js";import"./url.6d3c9ba6.js";import"./colorHelpers.2d661043.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fcf4c434-7289-4654-b512-98ba9f3f6aa1",e._sentryDebugIdIdentifier="sentry-dbid-fcf4c434-7289-4654-b512-98ba9f3f6aa1")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(t,r)=>(c(),f("div",null,[a(o(u),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.d175c3ea.js.map
