import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.75ae5be0.js";import{R as f}from"./tasksController.cf29452d.js";import{d as _,ea as y,f as g,o as n,Y as b,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.f34a21df.js";import"./gateway.2694bf1d.js";import{a as j,B as x}from"./build.b208dc32.js";import{a as C}from"./project.74b7e3d5.js";import"./tables.04ce2dd0.js";import{a as D}from"./asyncComputed.398aef1d.js";import"./metadata.d6db5c15.js";import"./PhRobot.vue.1bff4557.js";import"./PhWebhooksLogo.vue.2cc97eed.js";import"./ant-design.0ea267a5.js";import"./string.258cabc4.js";import"./dayjs.a4679024.js";import"./index.9470b370.js";import"./scripts.6e6452b0.js";import"./record.ca0bcbf9.js";import"./linters.659f9757.js";import"./polling.d60cf48f.js";import"./popupNotifcation.5e450e3b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="61743140-52c3-4827-9e45-380ff110690f",e._sentryDebugIdIdentifier="sentry-dbid-61743140-52c3-4827-9e45-380ff110690f")}catch{}})();const U=_({__name:"Tasks",setup(e){const s=y().params.projectId,p=new f(s),{result:o}=D(async()=>{const r=(await j.list(s)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([x.get(r.id),C.get(s)]);return{buildSpec:u,project:c}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),b(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.231f3d00.js.map
