import{P as f}from"./PlayerNavbar.1bb9a11c.js";import{d as g,eo as h,ea as c,e as y,f as b,r as k,o as i,Y as v,u as a,c as w,S as L,a as C,b as I,a0 as N}from"./index.f34a21df.js";import{u as V}from"./workspaceStore.26e825e1.js";import"./metadata.d6db5c15.js";import"./PhRobot.vue.1bff4557.js";import"./PhWebhooksLogo.vue.2cc97eed.js";import"./LoadingOutlined.15722362.js";import"./PhSignOut.vue.3c8aefbc.js";import"./index.562c81b6.js";import"./Avatar.29f914ec.js";import"./url.6d3c9ba6.js";import"./colorHelpers.2d661043.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="3125466c-dd12-4f41-948a-d47b658579c3",o._sentryDebugIdIdentifier="sentry-dbid-3125466c-dd12-4f41-948a-d47b658579c3")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,n=y(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.27798169.js.map
