import{k as n,T as a,m as r,P as o,C as p,M as d,s as c,n as s,p as m,q as u,t as f,v as g}from"./index.f34a21df.js";import{s as y,c as l,a as i}from"./workspaceStore.26e825e1.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.eb1d2992.js";import"./url.6d3c9ba6.js";import"./colorHelpers.2d661043.js";import"./PlayerConfigProvider.5238fda3.js";import"./index.b0f063d3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4a0542c5-2203-4647-8295-86684b692ee1",t._sentryDebugIdIdentifier="sentry-dbid-4a0542c5-2203-4647-8295-86684b692ee1")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=n({render:()=>m(b)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",d),e.component("Message",c),s(e,u),s(e,f),s(e,g)})();
//# sourceMappingURL=player.8d3b0674.js.map
