import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.35344f0f.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.f34a21df.js";import"./gateway.2694bf1d.js";import"./popupNotifcation.5e450e3b.js";import"./fetch.5afcaaee.js";import"./record.ca0bcbf9.js";import"./SaveButton.2694f150.js";import"./UnsavedChangesHandler.7c0bdd14.js";import"./ExclamationCircleOutlined.2b98fb49.js";import"./CrudView.b22901d4.js";import"./router.2b2bf682.js";import"./Badge.71e1a2a7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bee69fdc.js";import"./BookOutlined.6615ca40.js";import"./url.6d3c9ba6.js";import"./PhDotsThreeVertical.vue.a865b0cd.js";import"./index.9470b370.js";import"./index.e62b176f.js";import"./asyncComputed.398aef1d.js";import"./polling.d60cf48f.js";import"./PhPencil.vue.06736d81.js";import"./index.1ed88b5f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d7e6b0ad-380d-43cb-94a2-3a8637b6be5c",o._sentryDebugIdIdentifier="sentry-dbid-d7e6b0ad-380d-43cb-94a2-3a8637b6be5c")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,u)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.6ff0c049.js.map
