import{d as i,o as p,c as n,w as m,b as s,u as t}from"./index.f34a21df.js";import"./linters.659f9757.js";import{W as a}from"./workspaces.f5532882.js";import{C as d}from"./ContentLayout.ad8d7282.js";import{_ as c,E as f}from"./View.vue_vue_type_script_setup_true_lang.35344f0f.js";import"./asyncComputed.398aef1d.js";import"./workspaceStore.26e825e1.js";import"./url.6d3c9ba6.js";import"./colorHelpers.2d661043.js";import"./record.ca0bcbf9.js";import"./gateway.2694bf1d.js";import"./popupNotifcation.5e450e3b.js";import"./fetch.5afcaaee.js";import"./SaveButton.2694f150.js";import"./UnsavedChangesHandler.7c0bdd14.js";import"./ExclamationCircleOutlined.2b98fb49.js";import"./CrudView.b22901d4.js";import"./router.2b2bf682.js";import"./Badge.71e1a2a7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bee69fdc.js";import"./BookOutlined.6615ca40.js";import"./PhDotsThreeVertical.vue.a865b0cd.js";import"./index.9470b370.js";import"./index.e62b176f.js";import"./polling.d60cf48f.js";import"./PhPencil.vue.06736d81.js";import"./index.1ed88b5f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7e6da88f-6166-4884-8d97-c94b29bc0ccb",o._sentryDebugIdIdentifier="sentry-dbid-7e6da88f-6166-4884-8d97-c94b29bc0ccb")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(p(),n(d,null,{default:m(()=>[s(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(a)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.f13ca701.js.map
